CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
73 lines
1.8 KiB
C++
73 lines
1.8 KiB
C++
#include "test_framework.hpp"
|
|
#include <vector>
|
|
|
|
// Basic LDS operations without conflicts
|
|
// Targets SQ_LDS_* counters
|
|
__global__ void lds_basic_kernel(float* output, const float* input) {
|
|
__shared__ float shared_mem[256];
|
|
|
|
int tid = threadIdx.x;
|
|
int gid = blockIdx.x * blockDim.x + threadIdx.x;
|
|
|
|
// Sequential LDS write (no bank conflicts)
|
|
shared_mem[tid] = input[gid];
|
|
__syncthreads();
|
|
|
|
// Sequential LDS read (no bank conflicts)
|
|
float val = shared_mem[tid];
|
|
|
|
// Some computation
|
|
val = val * 2.0f + 1.0f;
|
|
|
|
// Another round of LDS operations
|
|
shared_mem[tid] = val;
|
|
__syncthreads();
|
|
|
|
val = shared_mem[tid];
|
|
|
|
output[gid] = val;
|
|
}
|
|
|
|
class LDSBasicTest : public test_framework::TestBase {
|
|
public:
|
|
LDSBasicTest() : TestBase("LDS Basic - Sequential Access") {}
|
|
|
|
bool setup() override {
|
|
size_ = 256 * 1024; // 256K elements (1024 blocks * 256 threads)
|
|
|
|
// Allocate device memory
|
|
d_input_ = hip_utils::allocateDeviceWithValue<float>(size_, 1.0f);
|
|
d_output_ = hip_utils::allocateDevice<float>(size_);
|
|
|
|
std::cout << " Array size: " << size_ << " elements" << std::endl;
|
|
std::cout << " LDS size per block: 256 floats (1 KB)" << std::endl;
|
|
|
|
return true;
|
|
}
|
|
|
|
bool execute() override {
|
|
dim3 block_size(256);
|
|
dim3 grid_size(size_ / block_size.x);
|
|
|
|
test_framework::KernelRunner runner("lds_basic_kernel", grid_size, block_size);
|
|
runner.launch(lds_basic_kernel, d_output_, d_input_);
|
|
|
|
return true;
|
|
}
|
|
|
|
void cleanup() override {
|
|
hip_utils::freeDevice(d_input_);
|
|
hip_utils::freeDevice(d_output_);
|
|
}
|
|
|
|
private:
|
|
float* d_input_ = nullptr;
|
|
float* d_output_ = nullptr;
|
|
size_t size_;
|
|
};
|
|
|
|
int main() {
|
|
LDSBasicTest test;
|
|
return test.run();
|
|
}
|